@@ -31,8 +31,8 @@ build_time_vars = {'ABIFLAGS': '',
            '-fcf-protection',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
- 'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/multibytecodec.h '
-                          '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/cjkcodecs.h',
+ 'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/multibytecodec.h '
+                          '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/cjkcodecs.h',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
@@ -61,7 +61,6 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed  '
                              '-Wl,-z,pack-relative-relocs -Wl,-z,now '
-                             '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld-errors '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
                              '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                              '-Wl,--build-id=sha1 '
@@ -98,19 +97,19 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.12.2/build/optimized/coverage.info',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.12.4/build/optimized/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.12.2/build/optimized/lcov-report',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.12.4/build/optimized/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.12.2/Include',
+             '-I/builddir/build/BUILD/Python-3.12.4/Include',
  'CXX': 'g++',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
- 'DEEPFREEZE_DEPS': '/builddir/build/BUILD/Python-3.12.2/Tools/build/deepfreeze.py '
+ 'DEEPFREEZE_DEPS': '/builddir/build/BUILD/Python-3.12.4/Tools/build/deepfreeze.py '
                     '_bootstrap_python '
-                    '/builddir/build/BUILD/Python-3.12.2/Programs/_freeze_module.py '
+                    '/builddir/build/BUILD/Python-3.12.4/Programs/_freeze_module.py '
                     '\\',
  'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
  'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.12 '
@@ -149,11 +148,11 @@ build_time_vars = {'ABIFLAGS': '',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FREEZE_MODULE': './_bootstrap_python '
-                  '/builddir/build/BUILD/Python-3.12.2/Programs/_freeze_module.py',
+                  '/builddir/build/BUILD/Python-3.12.4/Programs/_freeze_module.py',
  'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
  'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
  'FREEZE_MODULE_DEPS': '_bootstrap_python '
-                       '/builddir/build/BUILD/Python-3.12.2/Programs/_freeze_module.py',
+                       '/builddir/build/BUILD/Python-3.12.4/Programs/_freeze_module.py',
  'FROZEN_FILES_IN': '\\',
  'FROZEN_FILES_OUT': '\\',
  'GETPGRP_HAVE_ARG': 0,
@@ -704,12 +703,12 @@ build_time_vars = {'ABIFLAGS': '',
                     '-fasynchronous-unwind-tables -fstack-clash-protection '
                     '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
                     '-fwrapv  -fprofile-use -fprofile-correction '
-                    '-I/builddir/build/BUILD/Python-3.12.2/Include/internal '
+                    '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
-                    '-I/builddir/build/BUILD/Python-3.12.2/Include -fPIC -fPIC',
+                    '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
- 'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/include '
+ 'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.4/Modules/_hacl/include '
                    '-D_BSD_SOURCE -D_DEFAULT_SOURCE -fno-strict-overflow '
                    '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
                    '-fexceptions -fcf-protection -fexceptions -fcf-protection '
@@ -740,9 +739,9 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
                    '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
                    '-fwrapv  -fprofile-use -fprofile-correction '
-                   '-I/builddir/build/BUILD/Python-3.12.2/Include/internal '
+                   '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.12.2/Include -fPIC -fPIC',
+                   '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
@@ -781,9 +780,9 @@ build_time_vars = {'ABIFLAGS': '',
                     '-fasynchronous-unwind-tables -fstack-clash-protection '
                     '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
                     '-fwrapv  -fprofile-use -fprofile-correction '
-                    '-I/builddir/build/BUILD/Python-3.12.2/Include/internal '
+                    '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
-                    '-I/builddir/build/BUILD/Python-3.12.2/Include -fPIC -fPIC',
+                    '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -814,7 +813,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.12.2/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.12.4/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'array  _asyncio  _bisect  _contextvars  _csv  _heapq  '
@@ -872,7 +871,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_BINASCII_CFLAGS': '-DUSE_ZLIB_CRC32 -DWITH_GZFILEOP',
  'MODULE_BINASCII_LDFLAGS': '-lz',
  'MODULE_BINASCII_STATE': 'yes',
- 'MODULE_CMATH_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/_math.h',
+ 'MODULE_CMATH_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/_math.h',
  'MODULE_CMATH_LDFLAGS': '-lm',
  'MODULE_CMATH_STATE': 'yes',
  'MODULE_DEPS_SHARED': 'Modules/config.c',
@@ -883,7 +882,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_FCNTL_STATE': 'yes',
  'MODULE_GRP_STATE': 'yes',
  'MODULE_ITERTOOLS_LDFLAGS': '',
- 'MODULE_MATH_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/_math.h',
+ 'MODULE_MATH_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/_math.h',
  'MODULE_MATH_LDFLAGS': '-lm',
  'MODULE_MATH_STATE': 'yes',
  'MODULE_MMAP_STATE': 'yes',
@@ -908,8 +907,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_TERMIOS_STATE': 'yes',
  'MODULE_TIME_LDFLAGS': '',
  'MODULE_TIME_STATE': 'yes',
- 'MODULE_UNICODEDATA_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/unicodedata_db.h '
-                            '/builddir/build/BUILD/Python-3.12.2/Modules/unicodename_db.h',
+ 'MODULE_UNICODEDATA_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/unicodedata_db.h '
+                            '/builddir/build/BUILD/Python-3.12.4/Modules/unicodename_db.h',
  'MODULE_UNICODEDATA_STATE': 'yes',
  'MODULE_XXLIMITED_35_STATE': 'yes',
  'MODULE_XXLIMITED_STATE': 'yes',
@@ -921,56 +920,56 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__ASYNCIO_STATE': 'yes',
  'MODULE__BISECT_STATE': 'yes',
  'MODULE__BLAKE2_CFLAGS': '',
- 'MODULE__BLAKE2_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2-config.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2-impl.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2b-load-sse2.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2b-load-sse41.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2b-ref.c '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2b-round.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2b.c '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2s-load-sse2.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2s-load-sse41.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2s-load-xop.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2s-ref.c '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2s-round.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2s.c '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/blake2module.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h',
+ 'MODULE__BLAKE2_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2-config.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2-impl.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2b-load-sse2.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2b-load-sse41.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2b-ref.c '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2b-round.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2b.c '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2s-load-sse2.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2s-load-sse41.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2s-load-xop.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2s-ref.c '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2s-round.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/impl/blake2s.c '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/_blake2/blake2module.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/hashlib.h',
  'MODULE__BLAKE2_LDFLAGS': '-lssl -lcrypto',
  'MODULE__BLAKE2_STATE': 'yes',
  'MODULE__BZ2_CFLAGS': '',
  'MODULE__BZ2_LDFLAGS': '-lbz2',
  'MODULE__BZ2_STATE': 'yes',
- 'MODULE__CODECS_CN_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/mappings_cn.h '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_CN_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/mappings_cn.h '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_CN_STATE': 'yes',
- 'MODULE__CODECS_HK_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/mappings_hk.h  '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_HK_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/mappings_hk.h  '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_HK_STATE': 'yes',
- 'MODULE__CODECS_ISO2022_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/mappings_jisx0213_pair.h '
-                                '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/alg_jisx0201.h '
-                                '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/emu_jisx0213_2000.h '
-                                '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/multibytecodec.h '
-                                '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_ISO2022_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                                '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/alg_jisx0201.h '
+                                '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/emu_jisx0213_2000.h '
+                                '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/multibytecodec.h '
+                                '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_ISO2022_STATE': 'yes',
- 'MODULE__CODECS_JP_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/mappings_jisx0213_pair.h '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/alg_jisx0201.h '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/emu_jisx0213_2000.h '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/mappings_jp.h '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_JP_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/alg_jisx0201.h '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/emu_jisx0213_2000.h '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/mappings_jp.h '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_JP_STATE': 'yes',
- 'MODULE__CODECS_KR_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/mappings_kr.h '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_KR_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/mappings_kr.h '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_KR_STATE': 'yes',
  'MODULE__CODECS_LDFLAGS': '',
- 'MODULE__CODECS_TW_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/mappings_tw.h '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_TW_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/mappings_tw.h '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_TW_STATE': 'yes',
  'MODULE__COLLECTIONS_LDFLAGS': '',
  'MODULE__CONTEXTVARS_STATE': 'yes',
@@ -979,7 +978,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CRYPT_STATE': 'yes',
  'MODULE__CSV_STATE': 'yes',
  'MODULE__CTYPES_CFLAGS': '-fno-strict-overflow',
- 'MODULE__CTYPES_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/_ctypes/ctypes.h',
+ 'MODULE__CTYPES_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/_ctypes/ctypes.h',
  'MODULE__CTYPES_LDFLAGS': '-L/usr/lib64/../lib64 -lffi -ldl',
  'MODULE__CTYPES_MALLOC_CLOSURE': '',
  'MODULE__CTYPES_STATE': 'yes',
@@ -997,23 +996,23 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__DBM_LDFLAGS': '-lgdbm_compat',
  'MODULE__DBM_STATE': 'yes',
  'MODULE__DECIMAL_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1',
- 'MODULE__DECIMAL_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/_decimal/docstrings.h',
+ 'MODULE__DECIMAL_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/_decimal/docstrings.h',
  'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
  'MODULE__DECIMAL_STATE': 'yes',
  'MODULE__ELEMENTTREE_CFLAGS': '',
- 'MODULE__ELEMENTTREE_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/pyexpat.c',
+ 'MODULE__ELEMENTTREE_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/pyexpat.c',
  'MODULE__ELEMENTTREE_STATE': 'yes',
  'MODULE__FUNCTOOLS_LDFLAGS': '',
  'MODULE__GDBM_CFLAGS': '',
  'MODULE__GDBM_LDFLAGS': '-lgdbm',
  'MODULE__GDBM_STATE': 'yes',
  'MODULE__HASHLIB_CFLAGS': '',
- 'MODULE__HASHLIB_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h',
+ 'MODULE__HASHLIB_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/hashlib.h',
  'MODULE__HASHLIB_LDFLAGS': '-lcrypto',
  'MODULE__HASHLIB_STATE': 'yes',
  'MODULE__HEAPQ_STATE': 'yes',
- 'MODULE__IO_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_io',
- 'MODULE__IO_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/_io/_iomodule.h',
+ 'MODULE__IO_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.4/Modules/_io',
+ 'MODULE__IO_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/_io/_iomodule.h',
  'MODULE__IO_LDFLAGS': '',
  'MODULE__IO_STATE': 'yes',
  'MODULE__JSON_STATE': 'yes',
@@ -1022,61 +1021,61 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__LZMA_CFLAGS': '',
  'MODULE__LZMA_LDFLAGS': '-llzma',
  'MODULE__LZMA_STATE': 'yes',
- 'MODULE__MD5_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h \\ '
+ 'MODULE__MD5_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/hashlib.h \\ '
                      'Modules/_hacl/Hacl_Hash_MD5.h '
                      'Modules/_hacl/Hacl_Hash_MD5.c',
  'MODULE__MD5_STATE': 'disabled',
- 'MODULE__MULTIBYTECODEC_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/multibytecodec.h',
+ 'MODULE__MULTIBYTECODEC_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/multibytecodec.h',
  'MODULE__MULTIBYTECODEC_STATE': 'yes',
- 'MODULE__MULTIPROCESSING_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_multiprocessing',
+ 'MODULE__MULTIPROCESSING_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.4/Modules/_multiprocessing',
  'MODULE__MULTIPROCESSING_STATE': 'yes',
  'MODULE__OPCODE_STATE': 'yes',
  'MODULE__OPERATOR_LDFLAGS': '',
  'MODULE__PICKLE_STATE': 'yes',
- 'MODULE__POSIXSHMEM_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_multiprocessing',
+ 'MODULE__POSIXSHMEM_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.4/Modules/_multiprocessing',
  'MODULE__POSIXSHMEM_LDFLAGS': '',
  'MODULE__POSIXSHMEM_STATE': 'yes',
  'MODULE__POSIXSUBPROCESS_STATE': 'yes',
  'MODULE__QUEUE_STATE': 'yes',
  'MODULE__RANDOM_STATE': 'yes',
  'MODULE__SCPROXY_STATE': 'n/a',
- 'MODULE__SHA1_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h '
+ 'MODULE__SHA1_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/hashlib.h '
                       '\\ Modules/_hacl/Hacl_Hash_SHA1.h '
                       'Modules/_hacl/Hacl_Hash_SHA1.c',
  'MODULE__SHA1_STATE': 'disabled',
- 'MODULE__SHA2_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h '
+ 'MODULE__SHA2_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/hashlib.h '
                       '\\ Modules/_hacl/libHacl_Hash_SHA2.a',
  'MODULE__SHA2_STATE': 'disabled',
- 'MODULE__SHA3_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h '
+ 'MODULE__SHA3_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/hashlib.h '
                       '\\ Modules/_hacl/Hacl_Hash_SHA3.h '
                       'Modules/_hacl/Hacl_Hash_SHA3.c',
  'MODULE__SHA3_STATE': 'disabled',
  'MODULE__SIGNAL_LDFLAGS': '',
- 'MODULE__SOCKET_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/socketmodule.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/addrinfo.h '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/getaddrinfo.c '
-                        '/builddir/build/BUILD/Python-3.12.2/Modules/getnameinfo.c',
+ 'MODULE__SOCKET_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/socketmodule.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/addrinfo.h '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/getaddrinfo.c '
+                        '/builddir/build/BUILD/Python-3.12.4/Modules/getnameinfo.c',
  'MODULE__SOCKET_STATE': 'yes',
- 'MODULE__SQLITE3_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_sqlite',
- 'MODULE__SQLITE3_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/_sqlite/connection.h '
-                         '/builddir/build/BUILD/Python-3.12.2/Modules/_sqlite/cursor.h '
-                         '/builddir/build/BUILD/Python-3.12.2/Modules/_sqlite/microprotocols.h '
-                         '/builddir/build/BUILD/Python-3.12.2/Modules/_sqlite/module.h '
-                         '/builddir/build/BUILD/Python-3.12.2/Modules/_sqlite/prepare_protocol.h '
-                         '/builddir/build/BUILD/Python-3.12.2/Modules/_sqlite/row.h '
-                         '/builddir/build/BUILD/Python-3.12.2/Modules/_sqlite/util.h',
+ 'MODULE__SQLITE3_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.4/Modules/_sqlite',
+ 'MODULE__SQLITE3_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/_sqlite/connection.h '
+                         '/builddir/build/BUILD/Python-3.12.4/Modules/_sqlite/cursor.h '
+                         '/builddir/build/BUILD/Python-3.12.4/Modules/_sqlite/microprotocols.h '
+                         '/builddir/build/BUILD/Python-3.12.4/Modules/_sqlite/module.h '
+                         '/builddir/build/BUILD/Python-3.12.4/Modules/_sqlite/prepare_protocol.h '
+                         '/builddir/build/BUILD/Python-3.12.4/Modules/_sqlite/row.h '
+                         '/builddir/build/BUILD/Python-3.12.4/Modules/_sqlite/util.h',
  'MODULE__SQLITE3_LDFLAGS': '-lsqlite3',
  'MODULE__SQLITE3_STATE': 'yes',
  'MODULE__SRE_LDFLAGS': '',
  'MODULE__SSL_CFLAGS': '',
- 'MODULE__SSL_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/_ssl.h '
-                     '/builddir/build/BUILD/Python-3.12.2/Modules/_ssl/cert.c '
-                     '/builddir/build/BUILD/Python-3.12.2/Modules/_ssl/debughelpers.c '
-                     '/builddir/build/BUILD/Python-3.12.2/Modules/_ssl/misc.c '
-                     '/builddir/build/BUILD/Python-3.12.2/Modules/_ssl_data.h '
-                     '/builddir/build/BUILD/Python-3.12.2/Modules/_ssl_data_111.h '
-                     '/builddir/build/BUILD/Python-3.12.2/Modules/_ssl_data_300.h '
-                     '/builddir/build/BUILD/Python-3.12.2/Modules/socketmodule.h',
+ 'MODULE__SSL_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/_ssl.h '
+                     '/builddir/build/BUILD/Python-3.12.4/Modules/_ssl/cert.c '
+                     '/builddir/build/BUILD/Python-3.12.4/Modules/_ssl/debughelpers.c '
+                     '/builddir/build/BUILD/Python-3.12.4/Modules/_ssl/misc.c '
+                     '/builddir/build/BUILD/Python-3.12.4/Modules/_ssl_data.h '
+                     '/builddir/build/BUILD/Python-3.12.4/Modules/_ssl_data_111.h '
+                     '/builddir/build/BUILD/Python-3.12.4/Modules/_ssl_data_300.h '
+                     '/builddir/build/BUILD/Python-3.12.4/Modules/socketmodule.h',
  'MODULE__SSL_LDFLAGS': '-lssl -lcrypto',
  'MODULE__SSL_STATE': 'yes',
  'MODULE__STATISTICS_LDFLAGS': '-lm',
@@ -1085,9 +1084,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__STRUCT_STATE': 'yes',
  'MODULE__SYMTABLE_LDFLAGS': '',
  'MODULE__TESTBUFFER_STATE': 'yes',
- 'MODULE__TESTCAPI_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/_testcapi/testcapi_long.h '
-                          '/builddir/build/BUILD/Python-3.12.2/Modules/_testcapi/parts.h '
-                          '/builddir/build/BUILD/Python-3.12.2/Modules/_testcapi/util.h',
+ 'MODULE__TESTCAPI_DEPS': '/builddir/build/BUILD/Python-3.12.4/Modules/_testcapi/testcapi_long.h '
+                          '/builddir/build/BUILD/Python-3.12.4/Modules/_testcapi/parts.h '
+                          '/builddir/build/BUILD/Python-3.12.4/Modules/_testcapi/util.h',
  'MODULE__TESTCAPI_STATE': 'yes',
  'MODULE__TESTCLINIC_STATE': 'yes',
  'MODULE__TESTIMPORTMULTIPLE_STATE': 'yes',
@@ -1185,9 +1184,9 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-clash-protection -fcf-protection '
                              '-mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
                              '-fwrapv  -fprofile-use -fprofile-correction '
-                             '-I/builddir/build/BUILD/Python-3.12.2/Include/internal '
+                             '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/builddir/build/BUILD/Python-3.12.2/Include '
+                             '-I/builddir/build/BUILD/Python-3.12.4/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare '
               '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
@@ -1222,7 +1221,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
                      '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE '
                      '-fPIC -fwrapv  -fprofile-use -fprofile-correction '
-                     '-I/builddir/build/BUILD/Python-3.12.2/Include/internal',
+                     '-I/builddir/build/BUILD/Python-3.12.4/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
@@ -1254,33 +1253,29 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
                    '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
                    '-fwrapv  -fprofile-use -fprofile-correction '
-                   '-I/builddir/build/BUILD/Python-3.12.2/Include/internal '
+                   '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.12.2/Include -fPIC '
+                   '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,pack-relative-relocs '
-                    '-Wl,-z,now '
-                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld-errors '
-                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
+                    '-Wl,-z,now -specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                     '-Wl,--build-id=sha1 '
                     '-specs=/usr/lib/rpm/redhat/redhat-package-notes  -g  '
                     '-fno-semantic-interposition -flto -fuse-linker-plugin '
                     '-ffat-lto-objects -flto-partition=none -g -Wl,-z,relro '
                     '-Wl,--as-needed  -Wl,-z,pack-relative-relocs -Wl,-z,now '
-                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld-errors '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                     '-Wl,--build-id=sha1 '
                     '-specs=/usr/lib/rpm/redhat/redhat-package-notes  -g',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.12.2/Include',
+                '-I/builddir/build/BUILD/Python-3.12.4/Include',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 1,
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed  '
                       '-Wl,-z,pack-relative-relocs -Wl,-z,now '
-                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld-errors '
                       '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
                       '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                       '-Wl,--build-id=sha1 '
@@ -1288,14 +1283,12 @@ build_time_vars = {'ABIFLAGS': '',
                       '-fno-semantic-interposition -flto -fuse-linker-plugin '
                       '-ffat-lto-objects -flto-partition=none -g -Wl,-z,relro '
                       '-Wl,--as-needed  -Wl,-z,pack-relative-relocs -Wl,-z,now '
-                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld-errors '
                       '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
                       '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                       '-Wl,--build-id=sha1 '
                       '-specs=/usr/lib/rpm/redhat/redhat-package-notes  -g',
  'PY_LDFLAGS_NOLTO': '-fno-lto -Wl,-z,relro -Wl,--as-needed  '
                      '-Wl,-z,pack-relative-relocs -Wl,-z,now '
-                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld-errors '
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                      '-Wl,--build-id=sha1 '
@@ -1337,9 +1330,9 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
                         '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE '
                         '-fPIC -fwrapv  -fprofile-use -fprofile-correction '
-                        '-I/builddir/build/BUILD/Python-3.12.2/Include/internal '
+                        '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/builddir/build/BUILD/Python-3.12.2/Include -fPIC',
+                        '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC',
  'PY_SUPPORT_TIER': 1,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
@@ -1351,7 +1344,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.2/build/optimized',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.4/build/optimized',
  'SCRIPTDIR': '/usr/lib64',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1461,7 +1454,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_testcapi   Modules/_xxtestfuzz   Modules/cjkcodecs   '
             'Modules/expat   Objects   Parser   Programs   Python   '
             'Python/frozen_modules   Python/deepfreeze',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.12.2/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.12.4/Tools/gdb/libpython.py',
  'STATIC_LIBPYTHON': 0,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -1472,12 +1465,12 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.2/build/optimized '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.4/build/optimized '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.2/build/optimized '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.4/build/optimized '
                './python -E '
-               '/builddir/build/BUILD/Python-3.12.2/Tools/scripts/run_tests.py',
+               '/builddir/build/BUILD/Python-3.12.4/Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
@@ -1487,10 +1480,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': '/builddir/build/BUILD/Python-3.12.2/Tools/build/update_file.py',
+ 'UPDATE_FILE': '/builddir/build/BUILD/Python-3.12.4/Tools/build/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.12',
- 'VPATH': '/builddir/build/BUILD/Python-3.12.2',
+ 'VPATH': '/builddir/build/BUILD/Python-3.12.4',
  'WASM_ASSETS_DIR': './usr',
  'WASM_STDLIB': './usr/lib/python3.12/os.py',
  'WHEEL_PKG_DIR': '/usr/share/python3-wheels',
@@ -1507,9 +1500,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.12.2/build/optimized',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.12.2',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.12.4/build/optimized',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.12.4',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.12.2'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.12.4'}
